aboutsummaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/test_framework/phpbb_ui_test_case.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/test_framework/phpbb_ui_test_case.php b/tests/test_framework/phpbb_ui_test_case.php
index 7b950a7d5d..e76c8cd159 100644
--- a/tests/test_framework/phpbb_ui_test_case.php
+++ b/tests/test_framework/phpbb_ui_test_case.php
@@ -79,12 +79,12 @@ class phpbb_ui_test_case extends phpbb_test_case
}
try {
- $capabilities = DesiredCapabilities::firefox();
+ $capabilities = DesiredCapabilities::chrome();
self::$webDriver = RemoteWebDriver::create(
self::$host . ':' . self::$port,
$capabilities,
- 60 * 1000, // 60 seconds connection timeout
- 60 * 1000 // 60 seconds request timeout
+ 30 * 1000, // 30 seconds connection timeout
+ 30 * 1000 // 30 seconds request timeout
);
} catch (WebDriverCurlException $e) {
self::markTestSkipped('PhantomJS webserver is not running.');